rfc3339_validator: A pure python RFC3339 validator
==================================================

Description
-----------

A pure python RFC3339 validator

License
-------

MIT license

Upstream Contact
----------------

https://pypi.org/project/rfc3339-validator/

